summaryrefslogtreecommitdiffstats
path: root/part/kxedocument.h
diff options
context:
space:
mode:
authorSlávek Banko <slavek.banko@axis.cz>2016-03-26 12:35:35 +0100
committerSlávek Banko <slavek.banko@axis.cz>2016-03-26 14:10:15 +0100
commit38dca4b75c471ddf950e2f9f03801c550d7d26fd (patch)
treef5923ce5d84971f1f394baf7411146f078c02fab /part/kxedocument.h
parente28665ce3b2e9ec6f09b4c021db7443cac3c4128 (diff)
downloadkxmleditor-38dca4b75c471ddf950e2f9f03801c550d7d26fd.tar.gz
kxmleditor-38dca4b75c471ddf950e2f9f03801c550d7d26fd.zip
Initial TQt conversion
Signed-off-by: Slávek Banko <slavek.banko@axis.cz>
Diffstat (limited to 'part/kxedocument.h')
-rw-r--r--part/kxedocument.h50
1 files changed, 25 insertions, 25 deletions
diff --git a/part/kxedocument.h b/part/kxedocument.h
index 2b78659..7379086 100644
--- a/part/kxedocument.h
+++ b/part/kxedocument.h
@@ -14,8 +14,8 @@
#include <kurl.h>
-#include <qobject.h>
-#include <qdom.h>
+#include <tqobject.h>
+#include <tqdom.h>
#include <kparts/part.h>
#include <kxmlguiclient.h>
@@ -23,7 +23,7 @@
#define SCHEMA_ATTRIBUTE "schemaLocation"
#define SCHEMA_ATTRIBUTE_XSI "xsi:schemaLocation"
-class QString;
+class TQString;
class KCommand;
@@ -39,21 +39,21 @@ Stores XML document data which can be manipulated by KXMLEditor application.
@author Adam Charytoniuk
*/
-class KXEDocument : public QObject, public QDomDocument, public KXMLGUIClient
+class KXEDocument : public TQObject, public TQDomDocument, public KXMLGUIClient
{
Q_OBJECT
public:
/** @short Constructor */
- KXEDocument(QObject *parent=0, const char *name=0);
+ KXEDocument(TQObject *parent=0, const char *name=0);
/** @short Destructor */
~KXEDocument();
/** @short Saves document into given file */
- bool save(const QString &);
+ bool save(const TQString &);
/** @short Loads document from given file */
- bool open(const QString &);
+ bool open(const TQString &);
/** @short Sets modification flag.
@@ -76,7 +76,7 @@ public:
@param node newly created node
*/
- void updateNodeCreated(const QDomNode & node);
+ void updateNodeCreated(const TQDomNode & node);
/** @short Notifies views about deleting node
@@ -84,14 +84,14 @@ public:
This will give a chanse to the views to remove that node visualization.
@param node that is going to be deleted
*/
- void updateNodeDeleted(const QDomNode & node);
+ void updateNodeDeleted(const TQDomNode & node);
/** @short Notifies views about element properties changes
Should be called after element name or element attributes are changed.
@param domElement element that has changed
*/
- void updateNodeChanged( const QDomElement & domElement );
+ void updateNodeChanged( const TQDomElement & domElement );
/** @short Notifies views after change char. data properties
@@ -99,21 +99,21 @@ public:
(including texts, comments, .CDATA sections).
@param node character data node that has changed
*/
- void updateNodeChanged( const QDomCharacterData & node ) ;
+ void updateNodeChanged( const TQDomCharacterData & node ) ;
/** @short Notifies views after change proc. instr. properties
Should be called after any processing intruction is changed.
@param domProcInstr processing instruction that has changed
*/
- void updateNodeChanged( const QDomProcessingInstruction &domProcInstr );
+ void updateNodeChanged( const TQDomProcessingInstruction &domProcInstr );
/** @short Notifies views after moving node
Should be called if any node in the document was moved.
@param node XML node that has been moved
*/
- void updateNodeMoved( const QDomNode & node );
+ void updateNodeMoved( const TQDomNode & node );
/** @short Removes spec. processing instruction from XML file.
@@ -121,24 +121,24 @@ public:
@warning Removes processing instruction from DomDocument children node list only (no subnodes are modiified).
@sa setSpecProcInstr()
*/
- void removeSpecProcInstr(const QString &target);
+ void removeSpecProcInstr(const TQString &target);
/** @short Adds or changes (if already exists) processing instruction.
- Processing instruction will be added as a child in QDomDocument object.
+ Processing instruction will be added as a child in TQDomDocument object.
@param target processing intruction target
@param data processing intruction data
@sa removeSpecProcInstr()
*/
- virtual void setSpecProcInstr(const QString& target, const QString& data);
+ virtual void setSpecProcInstr(const TQString& target, const TQString& data);
- /** @short Returns processing instruction located in QDomDocument.
+ /** @short Returns processing instruction located in TQDomDocument.
If given processing intruction is not found, null node is returned.
@param target name of the processing instruction target.
@sa setSpecProcInstr()
*/
- QDomNode getSpecProcInstr(const QString& target);
+ TQDomNode getSpecProcInstr(const TQString& target);
/** @short Attaches stylesheet to current XML file.
@@ -192,7 +192,7 @@ public:
KCommand * actAttachSchema();
private:
- QString m_strCompressedTarEntryName;
+ TQString m_strCompressedTarEntryName;
/** Equals true if document was opened from compressed file */
bool m_bDocIsCompressed;
/** @short Stores modification flag */
@@ -218,11 +218,11 @@ signals:
void sigURLChanged(KURL url);
/** @short Emitted when new node was added to document.*/
- void sigNodeCreated(const QDomNode & node);
+ void sigNodeCreated(const TQDomNode & node);
/** @short Emitted everytime node was deleted from document.*/
- void sigNodeDeleted(const QDomNode & node);
+ void sigNodeDeleted(const TQDomNode & node);
/** @short Emitted everytime document element was changed .*/
- void sigNodeChanged( const QDomElement & domElement );
+ void sigNodeChanged( const TQDomElement & domElement );
/** @short Emitted everytime character data node was changed.
This is the case for nodes like:
@@ -230,11 +230,11 @@ signals:
- comments,
- CDATA sections,
*/
- void sigNodeChanged( const QDomCharacterData & node ) ;
+ void sigNodeChanged( const TQDomCharacterData & node ) ;
/** @short Emitted everytime processing instruction in document was changed .*/
- void sigNodeChanged( const QDomProcessingInstruction &domProcInstr );
+ void sigNodeChanged( const TQDomProcessingInstruction &domProcInstr );
/** @short Emitted everytime document node was moved was changed .*/
- void sigNodeMoved( const QDomNode & node );
+ void sigNodeMoved( const TQDomNode & node );
};
#endif